.. _reference_guide_sec:

pylibtemplate reference guide
=============================

.. autosummary::
   :toctree: _autosummary
   :template: custom_module_template.rst
   :recursive:

   pylibtemplate
